@@ -13,7 +13,7 @@ class GenerateArgs:
 def parse_content_to_function_call(content, **args: GenerateArgs):
     tools = args.get('tools')
     if tools is None:
-        return True, content
+        return True, False, content
     if 'function_response' in content:
         return False, False, 'This is a function response, not a function call. Please provide a function call.'
     try:
@@ -28,7 +28,6 @@ def parse_content_to_function_call(content, **args: GenerateArgs):
         for function in function_calls_validate:
             function.validate()
             function.validate_arguments(tools)
-        print('function_calls', function_calls)
         return True, True, function_calls
     except Exception as e:
         print('Error', e)
@@ -112,7 +111,7 @@ class CompletionController(CompletionModel):
                 break
             retry -= 1
         return {
-            'role': 'fuction_call',
+            'role': 'function_call',
             'content': response
         } if has_func \
             else {
